@@ -1,14 +1,25 @@
 import os
-import sys
 import tempfile
 
 
 def interact(modules=['n'], mode=''):
     command = 'from fxy.{} import *'
 
+    annotation = lambda x: {
+        'n': 'from mpmath import *',
+        's': 'from __future__ import division; from sympy import *; x, y, z = symbols("xyz"); k, m, n = symbols("kmn", integer=True)',
+        'a': 'numpy & np, pandas & pd, xarray & xr, scipy & sp, scipy.stats & st, statsmodels & sm, statsmodels.formula.api & smf',
+        'l': 'from . import __sklearn__ as sklearn; xgboost & xgb',
+        'p': 'matplotlib.pyplot & plt; matplotlib; seaborn & sns'
+    }.get(x) or ''
+
     # BPython
     if mode == 'b':
-        commands = '\n'.join([command.format(module) for module in modules]) + '\n'
+
+        commands = '\n'.join([
+            command.format(module) + ' # ' + str(annotation(module))
+            for module in modules]) + '\n'
+
         with tempfile.NamedTemporaryFile(mode='wt', delete=False) as f:
             f.write(commands)
         os.system(f'{mode}python -i -q -p {f.name}')
@@ -47,11 +58,11 @@ def main():
     p = not args.plotting
 
 
-    if i or sys.platform.startswith('win'):
-        mode = 'i'
-    else:
-        # Default is plain BPython shell for faster loading +  providing educational info.
+    if b:
         mode = 'b'
+    else:
+        # Default is plain IPython shell, cause more common.
+        mode = 'i'
 
     # Default is MPMath for "calculator"
     modules = ['n']
